@@ -44,16 +44,16 @@ typemap = {
     "void": "None",
 }
 
-LPAR, RPAR, LBRACE, RBRACE, COMMA, SEMI = map(Suppress, "(){},;")
-ident = Word(alphas, alphanums + "_")
+LPAR, RPAR, LBRACE, RBRACE, COMMA, SEMI = Suppress.using_each("(){},;")
+ident = pyparsing_common.identifier
 integer = Regex(r"[+-]?\d+")
 hexinteger = Regex(r"0x[0-9a-fA-F]+")
 
 const = Suppress("const")
-primitiveType = oneOf(t for t in typemap if not t.endswith("*"))
+primitiveType = one_of(t for t in typemap if not t.endswith("*"))
 structType = Suppress("struct") + ident
 vartype = (
-    Optional(const) + (primitiveType | structType | ident) + Optional(Word("*")("ptr"))
+    Opt(const) + (primitiveType | structType | ident) + Opt(Word("*")("ptr"))
 )
 
 
@@ -64,14 +64,14 @@ def normalizetype(t):
         # ~ return ret
 
 
-vartype.setParseAction(normalizetype)
+vartype.set_parse_action(normalizetype)
 
-arg = Group(vartype("argtype") + Optional(ident("argname")))
+arg = Group(vartype("argtype") + Opt(ident("argname")))
 func_def = (
     vartype("fn_type")
     + ident("fn_name")
     + LPAR
-    + Optional(delimitedList(arg | "..."))("fn_args")
+    + Opt(DelimitedList(arg | "..."))("fn_args")
     + RPAR
     + SEMI
 )
@@ -82,7 +82,7 @@ def derivefields(t):
         t["varargs"] = True
 
 
-func_def.setParseAction(derivefields)
+func_def.set_parse_action(derivefields)
 
 fn_typedef = "typedef" + func_def
 var_typedef = "typedef" + primitiveType("primType") + ident("name") + SEMI
@@ -90,10 +90,10 @@ var_typedef = "typedef" + primitiveType("primType") + ident("name") + SEMI
 enum_def = (
     Keyword("enum")
     + LBRACE
-    + delimitedList(Group(ident("name") + "=" + (hexinteger | integer)("value")))(
+    + DelimitedList(Group(ident("name") + "=" + (hexinteger | integer)("value")))(
         "evalues"
     )
-    + Optional(COMMA)
+    + Opt(COMMA)
     + RBRACE
 )
 
@@ -135,13 +135,13 @@ def typeAsCtypes(typestr):
 
 
 # scan input header text for primitive typedefs
-for td, _, _ in var_typedef.scanString(c_header):
+for td, _, _ in var_typedef.scan_string(c_header):
     typedefs.append((td.name, td.primType))
     # add typedef type to typemap to map to itself
     typemap[td.name] = td.name
 
 # scan input header text for function typedefs
-fn_typedefs = fn_typedef.searchString(c_header)
+fn_typedefs = fn_typedef.search_string(c_header)
 # add each function typedef to typemap to map to itself
 for fntd in fn_typedefs:
     typemap[fntd.fn_name] = fntd.fn_name
@@ -149,7 +149,7 @@ for fntd in fn_typedefs:
 # scan input header text, and keep running list of user-defined types
 for fn, _, _ in (
     cStyleComment.suppress() | fn_typedef.suppress() | func_def
-).scanString(c_header):
+).scan_string(c_header):
     if not fn:
         continue
     getUDType(fn.fn_type)
@@ -160,8 +160,8 @@ for fn, _, _ in (
     functions.append(fn)
 
 # scan input header text for enums
-enum_def.ignore(cppStyleComment)
-for en_, _, _ in enum_def.scanString(c_header):
+enum_def.ignore(cpp_style_comment)
+for en_, _, _ in enum_def.scan_string(c_header):
     for ev in en_.evalues:
         enum_constants.append((ev.name, ev.value))
 
