@@ -33,3 +33,18 @@ class TestExamples(unittest.TestCase):
 
     def test_select_parser(self):
         self._run("select_parser")
+
+    def test_booleansearchparser(self):
+        self._run("booleansearchparser")
+
+    def test_rosettacode(self):
+        self._run("rosettacode")
+
+    def test_excelExpr(self):
+        self._run("excel_expr")
+
+    def test_lucene_grammar(self):
+        self._run("lucene_grammar")
+
+    def test_range_check(self):
+        self._run("range_check")
